@@ -28,20 +28,20 @@ import re
 _pkg_config = {
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
-    'default_mod_dir':    '/usr/lib/python3.7/site-packages',
+    'default_mod_dir':    '/usr/lib/python3.8/site-packages',
     'default_sip_dir':    '/usr/share/sip',
     'deployment_target':  '',
     'platform':           'linux-g++',
-    'py_conf_inc_dir':    '/usr/include/python3.7m',
-    'py_inc_dir':         '/usr/include/python3.7m',
-    'py_lib_dir':         '/usr/lib/python3.7/config',
-    'py_version':         0x030704,
+    'py_conf_inc_dir':    '/usr/include/python3.8',
+    'py_inc_dir':         '/usr/include/python3.8',
+    'py_lib_dir':         '/usr/lib/python3.8/config',
+    'py_version':         0x030800,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
     'sip_config_args':    'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
-    'sip_inc_dir':        '/usr/include/python3.7m',
-    'sip_module_dir':     '/usr/lib/python3.7/site-packages',
-    'sip_root_dir':       '/usr/lib/python3.7/site-packages',
+    'sip_inc_dir':        '/usr/include/python3.8',
+    'sip_module_dir':     '/usr/lib/python3.8/site-packages',
+    'sip_root_dir':       '/usr/lib/python3.8/site-packages',
     'sip_version':        0x041313,
     'sip_version_str':    '4.19.19',
     'universal':          ''
